!FILE       :	array_allocation.f90
!UNIT NAME  :	array_allocation	(SUBROUTINE)
!DESCRIPTION:	This subroutine initialized some arrays and values before starting the time loop.
!		The allocatable arrays are initialized here, this is in order to avoid reinitialization
!		of the arrays within the time loop
!		Written by Joel GUERRERO o
!		REV01-01/2007, REV02-09/2020
!		Email: joegi.geo@yahoo.com

subroutine array_allocation

use shared_data

implicit none



!NUMBER OF VERTICES   		=>  n_ver
!NUMBER OF TRIANGLES  		=>  n_ele
!NUMBER OF CONSERVATIVE VALUES 	=>  num_var



!****************************************************************************************
!LOCAL VARIABLES DECLARATION

num_var=6

!allocate(reylam(n_ver))						!FOR FUTURE TURBULENCE MODEL IMPLEMENTATION
!allocate(reyturb(n_ver))						!FOR FUTURE TURBULENCE MODEL IMPLEMENTATION
allocate(array_delta_time(n_ele))					!ARRAY OF DELTA T MINIMM TIME STEP BY CELL

allocate(convar_exchange(num_var,n_ver))				!ARRAY OF CONSERVATIVE VALUES
!allocate(convar_exchange(6,n_ver))					!ARRAY OF CONSERVATIVE VALUES

allocate(dx_grad(4,n_ver))						!ARRAY OF NODAL GRADIENTS
allocate(dy_grad(4,n_ver))						!ARRAY OF NODAL GRADIENTS

!allocate(flu_turb(real_nedg))						!NOT YET USED FOR TURBULENCE USED

allocate(vel_u(n_ver))							!VELOCITIES ARRAY
allocate(vel_v(n_ver))							!VELOCITIES ARRAY
allocate(vel_tot(n_ver))						!VELOCITIES ARRAY

allocate(temperature_array(n_ver))					!TEMPERATURE ARRAY

!
!ATTENTION: ALL DUMMY VARIABLES DECLARED AS LOCAL VARIABLES ARE TEMPORAL
!THEY ARE ONLY USED WITHIN THE SUBROUTINE
!****************************************************************************************



end subroutine array_allocation
