!FILE       :	cell_cfl.f90
!UNIT NAME  :	cell_cfl	(SUBROUTINE)
!DESCRIPTION:	This subroutine computes the cell cfl number
!		Written by Joel GUERRERO
!		REV01-01/2007
!		Email: joegi.geo@yahoo.com

subroutine cell_cfl


use shared_data

implicit none





!****************************************************************************************



!****************************************************************************************
!LOCAL VARIABLES DEFINITION
cfl_viscoef	=	0.0
dtmin		=	1.0e+12					!VERY BIG NUMBER TO USE TO FIND THE DT MIN
!
!ATTENTION: ALL DUMMY VARIABLES DECLARED AS LOCAL VARIABLES ARE TEMPORAL
!THEY ARE ONLY USED WITHIN THE SUBROUTINE         
!****************************************************************************************



!****************************************************************************************
!LOCAL CFL COMPUTATION
!
do is=1,n_ver
			                                       
    vel_norm					=	sqrt(vars_actual(2,is)*vars_actual(2,is) &
							+ vars_actual(3,is)*vars_actual(3,is))

    sigmax					=	gam*pres(is)/vars_actual(1,is)
    sigmax					=	max(1.e-5,sqrt(sigmax)+vel_norm)
	array_delta_time(is)			=	cfl*array_ele_lenght(is)/sigmax
    dtmin					=	min(dtmin, array_delta_time(is))

enddo
!****************************************************************************************



!****************************************************************************************
!IF ITS UNSTEADY THEN DO
!
if (time_type .eq. 0) then
	do is=1,n_ver
    
		array_delta_time(is)    = dtmin
         
	enddo        
endif
!****************************************************************************************
            

!****************************************************************************************
!HERE ALSO CAN BE ADDED A LOOP IN ORDER TO SET A FIXED MINIMUN TIME STEP INSTEAD OF SETTING CFL NUMBER
!

!****************************************************************************************



!****************************************************************************************
!DELTA T AND TIME SETTING
!			
delta_time					=	min(dtmin, time_max-time_actual)
time_actual					=	time_actual + delta_time
!****************************************************************************************


end subroutine cell_cfl
