!FILE       :	convective_fluxes.f90
!UNIT NAME  :	convective_fluxes (SUBROUTINE)
!DESCRIPTION:	This subroutine computes convective fluxes at boundaries
!		Written by Joel GUERRERO
!		REV01-01/2007
!		Email: joegi.geo@yahoo.com

subroutine convective_fluxes


use shared_data

implicit none






!****************************************************************************************
!LOCAL VARIABLES DECLARATION
!
real::c_soundvel					!speed of sound
!
!ATTENTION: ALL DUMMY VARIABLES DECLARED AS LOCAL VARIABLES ARE TEMPORAL
!THEY ARE ONLY USED WITHIN THE SUBROUTINE
!****************************************************************************************



!****************************************************************************************
!VERTICES ON THE BODY -	SLIP BOUNDARY CONDITION -
!
do i=1,num_slip_ver

	is=array_slip_ver(i)

	convar_exchange(2,is)  = convar_exchange(2,is) - cv_normals_br(is)*cv_normals_bx(is)*pres(is)
	convar_exchange(3,is)  = convar_exchange(3,is) - cv_normals_br(is)*cv_normals_by(is)*pres(is)

enddo
!****************************************************************************************



!****************************************************************************************
!VERTICES ON THE UPSTREAM BOUNDARY -INLET-
!
loop_ver_ups_boun:do i=1,num_inlet_ver

	is					=	array_inlet_ver(i)
	temprxy_cvnormals      		 	=	cv_normals_br(is)
	tempx_cvnormals				=	cv_normals_bx(is)
    	tempy_cvnormals				=	cv_normals_by(is)
    	temp_u					=	vars_actual(2,is)/vars_actual(1,is)
    	temp_v					=	vars_actual(3,is)/vars_actual(1,is)
    	c_soundvel				=	sqrt(gam*pres(is)/vars_actual(1,is))
    	usc					=	1.0/c_soundvel
    	uq41					=	0.5*(temp_u*temp_u + temp_v*temp_v)*usc + gam4*c_soundvel
    	uq42					=	tempx_cvnormals*temp_u + tempy_cvnormals*temp_v


!*******************************************
!COMPUTATION A-(WI).WINF
!
	vp1       = (tempx_cvnormals*temp_u + tempy_cvnormals*temp_v)*temprxy_cvnormals 
    	vp3       = min(vp1 + c_soundvel*temprxy_cvnormals, 0.0)
    	vp4       = min(vp1 - c_soundvel*temprxy_cvnormals, 0.0)
    	vp1       = min(vp1, 0.0)

    	fdc1  = vp1*(rho_in + gam1*usc*usc*(-0.5*(temp_u*temp_u + temp_v*temp_v)*rho_in + temp_u*momxin + temp_v*momyin - ener_in))

    	fdc2  = vp1*((tempx_cvnormals*temp_v - tempy_cvnormals*temp_u)*rho_in + tempy_cvnormals*momxin - tempx_cvnormals*momyin)

    	fdc3  = vp3*(0.5*(-uq42*rho_in + tempx_cvnormals*momxin + tempy_cvnormals*momyin) + 0.5*gam1*usc*(0.5*(temp_u*temp_u + &
		temp_v*temp_v)*rho_in - temp_u*momxin - temp_v*momyin + ener_in))

    	fdc4  = vp4*(0.5*(uq42*rho_in - tempx_cvnormals*momxin - tempy_cvnormals*momyin)  + 0.5*gam1*usc*(0.5*(temp_u*temp_u + &
		temp_v*temp_v)*rho_in - temp_u*momxin - temp_v*momyin + ener_in))

    	fgp1  = fdc1 + usc*(fdc3 + fdc4)

    	fgp2  = temp_u*fdc1 + tempy_cvnormals*fdc2 + (temp_u*usc + tempx_cvnormals)*fdc3 + (temp_u*usc - tempx_cvnormals)*fdc4

    	fgp3  = temp_v*fdc1 - tempx_cvnormals*fdc2  + (temp_v*usc + tempy_cvnormals)*fdc3 + (temp_v*usc - tempy_cvnormals)*fdc4

    	fgp4  = 0.5*(temp_u*temp_u + temp_v*temp_v)*fdc1 + (tempy_cvnormals*temp_u - tempx_cvnormals*temp_v)*fdc2  &
		+ (uq41 + uq42)*fdc3   + (uq41 - uq42)*fdc4


!*******************************************
    convar_exchange(1,is)  = convar_exchange(1,is) - fgp1
    convar_exchange(2,is)  = convar_exchange(2,is) - fgp2
    convar_exchange(3,is)  = convar_exchange(3,is) - fgp3
    convar_exchange(4,is)  = convar_exchange(4,is) - fgp4
    convar_exchange(5,is)  = convar_exchange(5,is) - fgp1*vars_actual(5,is)/vars_actual(1,is)
    convar_exchange(6,is)  = convar_exchange(6,is) - fgp1*vars_actual(6,is)/vars_actual(1,is)


!*******************************************
!COMPUTATION OF A+(WI).WI
!
    	vp1   = (tempx_cvnormals*temp_u + tempy_cvnormals*temp_v)*temprxy_cvnormals 
    	vp3   = max(vp1 + c_soundvel*temprxy_cvnormals, 0.0)
    	vp4   = max(vp1 - c_soundvel*temprxy_cvnormals, 0.0)
    	vp1   = max(vp1, 0.0)

    	fdc1  = vp1*(vars_actual(1,is) + gam1*usc*usc*(-0.5*(temp_u*temp_u + temp_v*temp_v)*vars_actual(1,is) + &
		temp_u*vars_actual(2,is) + temp_v*vars_actual(3,is) - vars_actual(4,is)))

    	fdc2  = vp1*((tempx_cvnormals*temp_v - tempy_cvnormals*temp_u)*vars_actual(1,is) + &
		tempy_cvnormals*vars_actual(2,is) - tempx_cvnormals*vars_actual(3,is))

   	fdc3  = vp3*(0.5*(-uq42*vars_actual(1,is) + tempx_cvnormals*vars_actual(2,is) + &
		tempy_cvnormals*vars_actual(3,is)) + 0.5*gam1*usc*(0.5*(temp_u*temp_u + temp_v*temp_v)*vars_actual(1,is) &
		- temp_u*vars_actual(2,is) - temp_v*vars_actual(3,is) + vars_actual(4,is)))

    	fdc4  = vp4*(0.5*(uq42*vars_actual(1,is)  - tempx_cvnormals*vars_actual(2,is) - &
		tempy_cvnormals*vars_actual(3,is)) + 0.5*gam1*usc*(0.5*(temp_u*temp_u + temp_v*temp_v)*vars_actual(1,is) - &
		temp_u*vars_actual(2,is) - temp_v*vars_actual(3,is) + vars_actual(4,is)))


    	fgp1  = fdc1 + usc*(fdc3 + fdc4)

    	fgp2  = temp_u*fdc1 + tempy_cvnormals*fdc2  + (temp_u*usc + tempx_cvnormals)*fdc3 + &
		(temp_u*usc - tempx_cvnormals)*fdc4

    	fgp3  = temp_v*fdc1 - tempx_cvnormals*fdc2  + (temp_v*usc + tempy_cvnormals)*fdc3 + &
		(temp_v*usc - tempy_cvnormals)*fdc4

    	fgp4  = 0.5*(temp_u*temp_u + temp_v*temp_v)*fdc1 + (tempy_cvnormals*temp_u - tempx_cvnormals*temp_v)*fdc2 + &
		(uq41 + uq42)*fdc3   + (uq41 - uq42)*fdc4


!*******************************************
    convar_exchange(1,is)  = convar_exchange(1,is) - fgp1
    convar_exchange(2,is)  = convar_exchange(2,is) - fgp2
    convar_exchange(3,is)  = convar_exchange(3,is) - fgp3
    convar_exchange(4,is)  = convar_exchange(4,is) - fgp4
    convar_exchange(5,is)  = convar_exchange(5,is) - fgp1*vars_actual(5,is)/vars_actual(1,is)
    convar_exchange(6,is)  = convar_exchange(6,is) - fgp1*vars_actual(6,is)/vars_actual(1,is)
	
enddo loop_ver_ups_boun
!****************************************************************************************	
	
		
	 
!****************************************************************************************
!VERTICES ON THE DOWNSTREAM BOUNDARY -OUTLET-
!
loop_ver_down_boun:do i=1,num_outlet_ver

	is				=	array_outlet_ver(i)
    	temprxy_cvnormals       	=	cv_normals_br(is)
    	tempx_cvnormals			=	cv_normals_bx(is)
    	tempy_cvnormals			=	cv_normals_by(is)
    	temp_u				=	vars_actual(2,is)/vars_actual(1,is)
    	temp_v				=	vars_actual(3,is)/vars_actual(1,is)
    	c_soundvel			=	sqrt(gam*pres(is)/vars_actual(1,is))
    	usc				=	1.0/c_soundvel
    	uq41				=	0.5*(temp_u*temp_u + temp_v*temp_v)*usc + gam4*c_soundvel
    	uq42				=	tempx_cvnormals*temp_u + tempy_cvnormals*temp_v


!*******************************************
!CONSTANT RIEMANN INVARIANTS FOR temp_u-c_soundvel
!
	pstar		=	pres_out
    	upd_rho_out	=	vars_actual(1,is)*(pstar/pres(is))**(1./gam)

    	vel_norm	=	sqrt(temp_u*temp_u+temp_v*temp_v)
   	vel_norm	=	vel_norm+2./gam1*(c_soundvel-sqrt(gam*pstar/upd_rho_out))

    	upd_momxout	=	momxout*vel_norm*upd_rho_out
    	upd_momyout	=	momyout*vel_norm*upd_rho_out
    	upd_ener_out	=	pstar/gam1+upd_rho_out*vel_norm*vel_norm*0.5


!*******************************************
!COMPUTATION OF A-(WI).WINF
!
	vp1       = 	(tempx_cvnormals*temp_u + tempy_cvnormals*temp_v)*temprxy_cvnormals 
    	vp3       = 	min(vp1 + c_soundvel*temprxy_cvnormals, 0.0)
    	vp4       = 	min(vp1 - c_soundvel*temprxy_cvnormals, 0.0)
    	vp1       = 	min(vp1, 0.0)

    	fdc1      = 	vp1*(upd_rho_out + gam1*usc*usc*(-0.5*(temp_u*temp_u + temp_v*temp_v)*upd_rho_out + &
			temp_u*upd_momxout + temp_v*upd_momyout - upd_ener_out))

    	fdc2      = 	vp1*((tempx_cvnormals*temp_v - tempy_cvnormals*temp_u)*upd_rho_out + &
			tempy_cvnormals*upd_momxout - tempx_cvnormals*upd_momyout)

    	fdc3      = 	vp3*(0.5*(-uq42*upd_rho_out + tempx_cvnormals*upd_momxout + tempy_cvnormals*upd_momyout) &
			+ 0.5*gam1*usc*(0.5*(temp_u*temp_u + temp_v*temp_v)*upd_rho_out - temp_u*upd_momxout - &
			temp_v*upd_momyout + upd_ener_out))

    	fdc4      = 	vp4*(0.5*(uq42*upd_rho_out  - tempx_cvnormals*upd_momxout - tempy_cvnormals*upd_momyout) + &
			0.5*gam1*usc*(0.5*(temp_u*temp_u + temp_v*temp_v)*upd_rho_out - temp_u*upd_momxout - &
			temp_v*upd_momyout + upd_ener_out))

    	fgp1      = 	fdc1 + usc*(fdc3 + fdc4)

    	fgp2      = 	temp_u*fdc1 + tempy_cvnormals*fdc2  + (temp_u*usc + tempx_cvnormals)*fdc3 + &
			(temp_u*usc - tempx_cvnormals)*fdc4
	
    	fgp3      = 	temp_v*fdc1 - tempx_cvnormals*fdc2  + (temp_v*usc + tempy_cvnormals)*fdc3 + &
			(temp_v*usc - tempy_cvnormals)*fdc4

    	fgp4	  = 	0.5*(temp_u*temp_u + temp_v*temp_v)*fdc1 + (tempy_cvnormals*temp_u - &
			tempx_cvnormals*temp_v)*fdc2 + (uq41 + uq42)*fdc3   + (uq41 - uq42)*fdc4


!*******************************************
    convar_exchange(1,is)  = convar_exchange(1,is) - fgp1
    convar_exchange(2,is)  = convar_exchange(2,is) - fgp2
    convar_exchange(3,is)  = convar_exchange(3,is) - fgp3
    convar_exchange(4,is)  = convar_exchange(4,is) - fgp4
    convar_exchange(5,is)  = convar_exchange(5,is) - fgp1*vars_actual(5,is)/vars_actual(1,is)
    convar_exchange(6,is)  = convar_exchange(6,is) - fgp1*vars_actual(6,is)/vars_actual(1,is)


!*******************************************
!COMPUTATION OF A+(WI).WI
!
	vp1       = 	(tempx_cvnormals*temp_u + tempy_cvnormals*temp_v)*temprxy_cvnormals 
    	vp3       = 	max(vp1 + c_soundvel*temprxy_cvnormals, 0.0)
    	vp4       = 	max(vp1 - c_soundvel*temprxy_cvnormals, 0.0)
    	vp1       = 	max(vp1        , 0.0)

    	fdc1      = 	vp1*(vars_actual(1,is) + gam1*usc*usc*(-0.5*(temp_u*temp_u + temp_v*temp_v)*vars_actual(1,is) &
			+ temp_u*vars_actual(2,is) + temp_v*vars_actual(3,is) - vars_actual(4,is)))

    	fdc2      = 	vp1*((tempx_cvnormals*temp_v - tempy_cvnormals*temp_u)*vars_actual(1,is) + &
			tempy_cvnormals*vars_actual(2,is) - tempx_cvnormals*vars_actual(3,is))

    	fdc3      = 	vp3*(0.5*(-uq42*vars_actual(1,is)+tempx_cvnormals*vars_actual(2,is) + &
			tempy_cvnormals*vars_actual(3,is))+0.5*gam1*usc*(0.5*(temp_u*temp_u + &
			temp_v*temp_v)*vars_actual(1,is)-temp_u*vars_actual(2,is)-temp_v*vars_actual(3,is)+vars_actual(4,is)))

    	fdc4      = 	vp4*(0.5*(uq42*vars_actual(1,is)-tempx_cvnormals*vars_actual(2,is) - &
			tempy_cvnormals*vars_actual(3,is))+0.5*gam1*usc*(0.5*(temp_u*temp_u + &
			temp_v*temp_v)*vars_actual(1,is)-temp_u*vars_actual(2,is)-temp_v*vars_actual(3,is)+vars_actual(4,is)))

    	fgp1      = 	fdc1 + usc*(fdc3 + fdc4)

    	fgp2      = 	temp_u*fdc1 + tempy_cvnormals*fdc2 + (temp_u*usc + tempx_cvnormals)*fdc3 + &
			(temp_u*usc - tempx_cvnormals)*fdc4

    	fgp3      = 	temp_v*fdc1 - tempx_cvnormals*fdc2  + (temp_v*usc + tempy_cvnormals)*fdc3 + &
			(temp_v*usc - tempy_cvnormals)*fdc4

    	fgp4      = 	0.5*(temp_u*temp_u + temp_v*temp_v)*fdc1 + (tempy_cvnormals*temp_u - &
			tempx_cvnormals*temp_v)*fdc2 + (uq41 + uq42)*fdc3 + (uq41 - uq42)*fdc4


!*******************************************
    convar_exchange(1,is)  = convar_exchange(1,is) - fgp1
    convar_exchange(2,is)  = convar_exchange(2,is) - fgp2
    convar_exchange(3,is)  = convar_exchange(3,is) - fgp3
    convar_exchange(4,is)  = convar_exchange(4,is) - fgp4
    convar_exchange(5,is)  = convar_exchange(5,is) - fgp1*vars_actual(5,is)/vars_actual(1,is)
    convar_exchange(6,is)  = convar_exchange(6,is) - fgp1*vars_actual(6,is)/vars_actual(1,is)



enddo loop_ver_down_boun
!****************************************************************************************



!****************************************************************************************
!
! 
do i=1,num_inpro_ver

	is=array_inpro_ver(i)
    	convar_exchange(1,is)  = 0.0
    	convar_exchange(2,is)  = 0.0
    	convar_exchange(3,is)  = 0.0
    	convar_exchange(4,is)  = 0.0
    	convar_exchange(5,is)  = 0.0
    	convar_exchange(6,is)  = 0.0

enddo
!****************************************************************************************



end subroutine convective_fluxes
