!FILE       :	edge_recons.f90
!UNIT NAME  :	edge_recons	(SUBROUTINE)
!DESCRIPTION:	This subroutine reconstruct edge structure for solver use
!		This is not the best way to do it, but it works
!		Feel free to modify this one or to use a better one, currently in trying
!		to came with a better way to do this.  For instance I will get the whole
!		edge structure directly from triangle mesher instead of rebuilding it within the solver
!		If you rebuild this you need the edge connectivity and the boundary edge connectvity 
!		Written by Joel GUERRERO
!		REV01-01/2007
!		Email: joegi.geo@yahoo.com

subroutine edge_recons


use shared_data

implicit none





!****************************************************************************************
!LOCAL VARIABLES DECLARATION
!
integer,parameter::nvmax = 15								!DUMMY VARIABLES MAXIMUM NUMBER OF ELEMENTS AROUND  VERTEX

integer::iseg		=0										!DUMMY VARIABLES
integer::connec_t1	=0										!DUMMY VARIABLES
integer::connec_t2	=0										!DUMMY VARIABLES
integer::connec_t3	=0										!DUMMY VARIABLES
integer::ele_ord	=0										!DUMMY VARIABLES TRIANGLE CONNECTION ORDERED 1-2-3
integer::ele_nex	=0										!DUMMY VARIABLES TRIANGLE CONNECTION ORDERED 2-3-1
integer::norm_boun1	=0										!DUMMY VARIABLES
integer::norm_boun2	=0										!DUMMY VARIABLES
!integer::real_nedg	=0										!******************* SET NAME
integer::n_boun_edg	=0										!******************* SET NAME
integer::temp0		=0										!DUMMY VARIABLES

integer,dimension(max_ele,nvmax,2)::nei_ele_array

integer,dimension(3)::array_ele_ord	=0							!DUMMY VARIABLES
integer,dimension(3)::array_ele_nex	=0							!DUMMY VARIABLES

real::esp	=0											!DUMMY VARIABLES *****  SPACING&ORIENTATION

real::vx	=0											!DUMMY VARIABLES *****  VERTICES NORMALS X
real::vy	=0											!DUMMY VARIABLES *****  VERTICES NORMALS Y

real,dimension(3)::dbxx,dbyy	=0						!DUMMY VARIABLES

save
!
!ATTENTION: ALL DUMMY VARIABLES DECLARED AS LOCAL VARIABLES ARE TEMPORAL
!THEY ARE ONLY USED WITHIN THE SUBROUTINE
!****************************************************************************************


temprxy_cvnormals	=0


!****************************************************************************************
!ARRAY ALLOCATION
!HERE max_edges=n_ver+n_ele	  !***MAXIMUM NUMBER OF EDGES PREVIOUSLY DEFINED IN read_mesh
!
allocate(edg_connec(2,max_edges))					!EDGE CONNECTIVITY
allocate(bound_connec(max_edges))					!BOUNDARY EDGE LIST
allocate(cv_normals(3,max_edges))					!CONTROL VOLUME NORMALS DEFINITION
allocate(cv_normals_bx(n_ver))						!BOUNDARY NORMAL X
allocate(cv_normals_by(n_ver))						!BOUNDARY NORMAL Y
allocate(cv_normals_br(n_ver))						!BOUNDARY NORMAL RESUL
!****************************************************************************************



!****************************************************************************************
array_ele_nex(1)                 = 2				!DUMMY VARIABLES  *****  TRIANGLE CONNECTION ORDERED 2-3-1
array_ele_nex(2)                 = 3				!DUMMY VARIABLES  *****  TRIANGLE CONNECTION ORDERED 2-3-1
array_ele_nex(3)                 = 1				!DUMMY VARIABLES  *****  TRIANGLE CONNECTION ORDERED 2-3-1
array_ele_ord(1)                 = 1				!DUMMY VARIABLES  *****  TRIANGLE CONNECTION ORDERED 1-2-3
array_ele_ord(2)                 = 2				!DUMMY VARIABLES  *****  TRIANGLE CONNECTION ORDERED 1-2-3
array_ele_ord(3)                 = 3				!DUMMY VARIABLES  *****  TRIANGLE CONNECTION ORDERED 1-2-3
!****************************************************************************************



!****************************************************************************************
do iseg=1,max_edges

	cv_normals(1,iseg)       = 0.0
	cv_normals(2,iseg)       = 0.0    
	cv_normals(3,iseg)       = 0.0 
	      
enddo


do i=1,n_ver
	do k=1,nvmax

		nei_ele_array(i,k,1)   = 0
		nei_ele_array(i,k,2)   = 0

	enddo
enddo


esp							= 1.0/6.0
real_nedg                   = 0
!****************************************************************************************



!****************************************************************************************
outer_loop1:do jt=1,n_ele

connec_t1                 = connectivity(1,jt)
connec_t2                 = connectivity(2,jt)
connec_t3                 = connectivity(3,jt)

x1                  = coor(1,connec_t1)
y1                  = coor(2,connec_t1)
x2                  = coor(1,connec_t2)
y2                  = coor(2,connec_t2)
x3                  = coor(1,connec_t3)
y3                  = coor(2,connec_t3)

dbxx(1)             = y2 - y3
dbxx(2)             = y3 - y1
dbxx(3)             = y1 - y2
dbyy(1)             = x3 - x2
dbyy(2)             = x1 - x3
dbyy(3)             = x2 - x1 
	   

!****************************************************************************************	                    
	inner_loop1:do k=1,3

    connec_t1              = connectivity(array_ele_ord(k),jt)
    connec_t2              = connectivity(array_ele_nex(k),jt)

    
		inner_loop1_1:do kv=1,nvmax

			outer_if1:if (nei_ele_array(connec_t1,kv,1) .eq. 0)then
			 
				exit inner_loop1_1

			elseif (nei_ele_array(connec_t1,kv,1) .eq. connec_t2) then

				temp0					= nei_ele_array(connec_t1,kv,2)
                norm_boun1				= iabs(edg_connec(1,temp0))
                edg_connec(1,temp0)		= -edg_connec(1,temp0)
                norm_boun2				= edg_connec(2,temp0)

                inner_if1:if (connec_t1 .eq. norm_boun1 .and. connec_t2 .eq. norm_boun2) then

					esp     = abs(esp)

                elseif (connec_t1 .eq. norm_boun2 .and. connec_t2 .eq. norm_boun1) then

					esp		=-abs(esp)

                else

					print*,'ERROR IN edge_recons.f90 (CHECK SUBROUTINE) ',connec_t1,connec_t2,norm_boun1,norm_boun2

                endif inner_if1

       
				!Computation of the control volume boundary normals
				cv_normals(1,temp0)     = cv_normals(1,temp0) +  esp*(dbxx(array_ele_ord(k)) - dbxx(array_ele_nex(k)))
				cv_normals(2,temp0)     = cv_normals(2,temp0) +  esp*(dbyy(array_ele_ord(k)) - dbyy(array_ele_nex(k)))

				cycle inner_loop1


			endif outer_if1

		enddo inner_loop1_1
!****************************************************************************************



!****************************************************************************************
        inner_loop2:do  kv=1,nvmax

			outer_if2:if (nei_ele_array(connec_t2,kv,1) .eq. 0) then
			 
				real_nedg  = real_nedg + 1

				if (real_nedg .gt. max_edges) then

					print*,'TRY INCREASING MAXIMUM NUMBER OF EDGES : ', max_edges
					stop 'CHECK SUBROUTINE edge_recons.f90'

				endif


				nei_ele_array(connec_t2,kv,1)		= connec_t1
				nei_ele_array(connec_t2,kv,2)		= real_nedg
				edg_connec(1,real_nedg)				= -connec_t1
				edg_connec(2,real_nedg)				= connec_t2
				temp0								= real_nedg
				esp									= abs(esp)


			    !Computation of the control volume boundary normals
				cv_normals(1,temp0)     = cv_normals(1,temp0) + esp*(dbxx(array_ele_ord(k)) - dbxx(array_ele_nex(k)))
				cv_normals(2,temp0)     = cv_normals(2,temp0) + esp*(dbyy(array_ele_ord(k)) - dbyy(array_ele_nex(k)))

				cycle inner_loop1

			endif outer_if2
!***********************************
!***********************************
            outer_if3:if (nei_ele_array(connec_t2,kv,1) .eq. connec_t1) then

				temp0					= nei_ele_array(connec_t2,kv,2)
                norm_boun1				= edg_connec(1,temp0)
                edg_connec(1,temp0)		= -edg_connec(1,temp0)
                norm_boun2				= edg_connec(2,temp0)

                inner_if3:if (connec_t1 .eq. norm_boun1 .and. connec_t2 .eq. norm_boun2) then

					esp     = abs(esp)

                else if (connec_t1 .eq. norm_boun2 .and. connec_t2 .eq. norm_boun1) then

					esp     =-abs(esp)

                else

                    print*,'ERROR IN edge_recons.f90 (CHECK SUBROUTINE)',connec_t1,connec_t2,norm_boun1,norm_boun2

				endif inner_if3


				!Computation of the control volume boundary normals
				cv_normals(1,temp0)     = cv_normals(1,temp0) + esp*(dbxx(array_ele_ord(k)) - dbxx(array_ele_nex(k)))
				cv_normals(2,temp0)     = cv_normals(2,temp0) + esp*(dbyy(array_ele_ord(k)) - dbyy(array_ele_nex(k)))

				cycle inner_loop1

			endif outer_if3

		enddo inner_loop2
!****************************************************************************************


        kv               = kv + 1

		if (kv .gt. nvmax) then

			print*,'TRY INCREASING NVMAX VARIABLE VALUE : ', nvmax
            stop 'CHECK SUBROUTINE edge_recons.f90'

		endif


	enddo inner_loop1

enddo outer_loop1
!****************************************************************************************



!****************************************************************************************
do iseg=1,real_nedg

	if (abs(cv_normals(1,iseg)).lt.1.0e-16.and.abs(cv_normals(2,iseg)).lt.1.0e-16) then

		cv_normals(1,iseg)   = 1.0e-8
        cv_normals(2,iseg)   = 1.0e-8

    endif

enddo
!****************************************************************************************



!****************************************************************************************
!Normalization of the control volume boundary normals & construction of the boundary edges
!
n_boun_edg                    = 0

do iseg=1,real_nedg

	temprxy_cvnormals		= sqrt(cv_normals(1,iseg)*cv_normals(1,iseg)+cv_normals(2,iseg)*cv_normals(2,iseg))
	cv_normals(1,iseg)      = cv_normals(1,iseg)/temprxy_cvnormals
	cv_normals(2,iseg)      = cv_normals(2,iseg)/temprxy_cvnormals
	cv_normals(3,iseg)      = temprxy_cvnormals
	norm_boun1				= edg_connec(1,iseg)


!BULLS EYE - This is a boundary edge
    if (norm_boun1 .lt. 0) then

		n_boun_edg						= n_boun_edg + 1
        bound_connec(n_boun_edg)        = iseg
        edg_connec(1,iseg)				= -edg_connec(1,iseg)

	endif

enddo
!****************************************************************************************



!****************************************************************************************
print *,'*********************************************'
print *,'TOTAL NUMBER OF EDGES    : ', real_nedg
print *,'NUMBER OF BOUNDARY EDGES : ', n_boun_edg
print *,'*********************************************'
print *


!Computation of the boundary vertices normals (tauy, -taux) *Watertightness
do is=1,n_ver

	cv_normals_bx(is)            = 0.0
	cv_normals_by(is)            = 0.0

enddo
!****************************************************************************************



!****************************************************************************************
do ifr=1,n_boun_edg

	iseg						= bound_connec(ifr)
    ele_ord						= edg_connec(1,iseg)
    ele_nex						= edg_connec(2,iseg)
    vx							= coor(2,ele_nex) - coor(2,ele_ord)
    vy							= coor(1,ele_ord) - coor(1,ele_nex)  
    cv_normals_bx(ele_ord)      = cv_normals_bx(ele_ord) + vx * 0.5
    cv_normals_by(ele_ord)      = cv_normals_by(ele_ord) + vy * 0.5
    cv_normals_bx(ele_nex)      = cv_normals_bx(ele_nex) + vx * 0.5
    cv_normals_by(ele_nex)      = cv_normals_by(ele_nex) + vy * 0.5 

enddo
!****************************************************************************************



!****************************************************************************************
do is=1,n_ver

	if(array_boundary_ver(is).ne.0) then

		cv_normals_br(is)	= sqrt(cv_normals_bx(is)**2+cv_normals_by(is)**2)
		cv_normals_bx(is)	= cv_normals_bx(is)/cv_normals_br(is)
		cv_normals_by(is)	= cv_normals_by(is)/cv_normals_br(is)

	else

		cv_normals_br(is)   = 0.0
		cv_normals_bx(is)	= 0.0
		cv_normals_by(is)	= 0.0

    endif

enddo
!****************************************************************************************



end subroutine edge_recons
