!FILE       :	ele_area.f90
!UNIT NAME  :	ele_area	(SUBROUTINE)
!DESCRIPTION:	This subroutine computes elments and control volumes areas
!		Written by Joel GUERRERO 
!		REV01-01/2007
!		Email: joegi.geo@yahoo.com

subroutine ele_area


use shared_data

implicit none





!****************************************************************************************
!LOCAL VARIABLES DECLARATION
!
real::a(2)	=0						!DUMMY VARIABLES
real::b(2)	=0						!DUMMY VARIABLES
real::c(2)	=0						!DUMMY VARIABLES

real::marker_1	=0						!DUMMY VARIABLES 
real::marker_2	=0						!DUMMY VARIABLES  
real::marker_3	=0						!DUMMY VARIABLES

real::vol	=0						!DUMMY VARIABLES					
real::sum_airt	=0						!ELEMENT AREA SUMMATION
real::sum_airs	=0						!CONTROL VOLUME AREA SUMMATION

!ATTENTION: ALL DUMMY VARIABLES DECLARED AS LOCAL VARIABLES ARE TEMPORAL
!THEY ARE ONLY USED WITHIN THE SUBROUTINE
!****************************************************************************************    



!****************************************************************************************
!ARRAYS ALLOCATION
!
allocate(area_cv(n_ver))					!ARRAY OF AREA CONTROL VOLUME
allocate(area_ele(n_ele))					!ARRAY OF AREA ELEMENTS
allocate(area_cv_mod(n_ver))					!ARRAY OF AREA CONTROL VOLUME
allocate(area_ele_mod(n_ele))					!ARRAY OF AREA ELEMENTS
!****************************************************************************************



temp_u		=0
temp_v		=0
temp_w		=0



!****************************************************************************************
!ARRAY INITIALIZATION
!
do i=1,n_ver

	area_cv(i)  = 0.0

enddo

do i=1,n_ele

	area_ele(i)  = 0.0

enddo

do i=1,n_ver

	area_cv_mod(i)  = 0.0

enddo

do i=1,n_ele

	area_ele_mod(i)  = 0.0

enddo
!****************************************************************************************



!****************************************************************************************
!ACTUAL AREA COMPUTATION
!
do j=1,n_ele

	marker_1       = connectivity(1,j)
	marker_2       = connectivity(2,j)
	marker_3       = connectivity(3,j)

!CURRENT TRIANGLE AREA COMPUTATIONa
	a(1)			= coor(1,marker_1)
	a(2)			= coor(2,marker_1)
	b(1)			= coor(1,marker_2)
	b(2)			= coor(2,marker_2)
	c(1)			= coor(1,marker_3)
	c(2)			= coor(2,marker_3)
	temp_u			= a(2)-c(2)
	temp_v			= c(1)-a(1)
	temp_w			= a(1)*c(2)-a(2)*c(1)
	vol			= temp_u*b(1)+temp_v*b(2)+temp_w
	area_ele(j)		= 0.5*abs(vol)


!GATHERING THE CURRENT TRIANGLE AREA INTO THE CONTROL VOLUME
	area_cv(marker_1) = area_cv(marker_1)+area_ele(j)/3.0
	area_cv(marker_2) = area_cv(marker_2)+area_ele(j)/3.0
	area_cv(marker_3) = area_cv(marker_3)+area_ele(j)/3.0

enddo
!****************************************************************************************



!****************************************************************************************
!NEW DATA
!
do i=1,n_ver

	area_cv_mod(i)=area_cv(i)
!   rrs(is)=1.0

enddo

do i=1,n_ele

	area_ele_mod(i)=1.0/area_ele(i)

enddo
!****************************************************************************************



!****************************************************************************************
!TOTAL AREA COMPUTATION ON ELEMENTS AN CONTROL VOLUMES
!
sum_airt=0.0

do i=1,n_ele

	sum_airt	=	sum_airt+area_ele(i)

enddo

sum_airs=0.0

do j=1,n_ver

	sum_airs	=	sum_airs+area_cv(j)

enddo


print *,'*********************************************'
print *,'ELEMENTS TOTAL AREA, sum area_ele =',sum_airt
print *,'CONTROL VOLUMES TOTAL AREA , sum area_cv =',sum_airs
print *,'AREAS DIFFERENCE =', abs(sum_airt-sum_airs)
print *,'*********************************************'
print *
!****************************************************************************************



end subroutine ele_area
