!FILE       :	ele_lenght.f90
!UNIT NAME  :	ele_lenght	(SUBROUTINE)
!DESCRIPTION:	This subroutine computes elements lenghts for dt computation
!		Written by Joel GUERRERO 
!		REV01-01/2007
!		Email: joegi.geo@yahoo.com

subroutine ele_lenght


use shared_data

implicit none





!****************************************************************************************
!LOCAL VARIABLES
!
real,dimension(3)::dbxx			=0				!DUMMY VARIABLES
real,dimension(3)::dbyy			=0				!DUMMY VARIABLES
real,dimension(3)::alto			=0				!DUMMY VARIABLES

real::len_tmp	=0							!DUMMY VARIABLES
real::alto_tmp	=0							!DUMMY VARIABLES
!
!ATTENTION: ALL DUMMY VARIABLES DECLARED AS LOCAL VARIABLES ARE TEMPORAL
!THEY ARE ONLY USED WITHIN THE SUBROUTINE
!****************************************************************************************



!****************************************************************************************
!ARRAY ALLOCATION
!
allocate(array_ele_lenght(n_ver))					!ARRAY OF ELEMENTS LENGHTS
!****************************************************************************************

!****************************************************************************************
!INIT VERTEX LEGHT
!
do is=1,n_ver

	array_ele_lenght(is)     = 1.0e+20
	
enddo
!****************************************************************************************



!****************************************************************************************
!ACTUAL LENGHT COMPUTATI0N
!
do jt=1,n_ele

	connectemp_1   = connectivity(1,jt)
	connectemp_2   = connectivity(2,jt)
	connectemp_3   = connectivity(3,jt)
	x1             = coor(1,connectemp_1)
	y1             = coor(2,connectemp_1)
	x2             = coor(1,connectemp_2)
	y2             = coor(2,connectemp_2)
	x3             = coor(1,connectemp_3)
	y3             = coor(2,connectemp_3)
	dbxx(1)        = y2 - y3
	dbxx(2)        = y3 - y1
	dbxx(3)        = y1 - y2
	dbyy(1)        = x3 - x2
	dbyy(2)        = x1 - x3
	dbyy(3)        = x2 - x1

	alto_tmp       = 1.0/(2.0*area_ele(jt))
	alto(1)        = alto_tmp*(sqrt(dbxx(1)*dbxx(1) + dbyy(1)*dbyy(1)))
	alto(2)        = alto_tmp*(sqrt(dbxx(2)*dbxx(2) + dbyy(2)*dbyy(2)))
	alto(3)        = alto_tmp*(sqrt(dbxx(3)*dbxx(3) + dbyy(3)*dbyy(3)))

	len_tmp            = min(1.0/alto(1),1.0/alto(2))
	len_tmp            = min(len_tmp,1.0/alto(3))

	array_ele_lenght(connectemp_1)  = min(array_ele_lenght(connectemp_1), len_tmp)
	array_ele_lenght(connectemp_2)  = min(array_ele_lenght(connectemp_2), len_tmp)
	array_ele_lenght(connectemp_3)  = min(array_ele_lenght(connectemp_3), len_tmp)

enddo
!****************************************************************************************



end subroutine ele_lenght
