!FILE       :	explicit_scheme.f90
!UNIT NAME  :	explicit_scheme (SUBROUTINE)
!DESCRIPTION:	This subroutine computes the explicit scheme formulation (KERNEL)
!		It calls convective_fluxes, roeflux & gradients
!		Written by Joel GUERRERO on 
!		REV01-01/2007
!		Email: joegi.geo@yahoo.com

subroutine explicit_scheme


use shared_data

implicit none





!****************************************************************************************
!SETTING VALUE OF convar_exchange ARRAY
!
do is=1,n_ver

	do ivar=1,num_var

		convar_exchange(ivar,is) = 0.0

	enddo

enddo
!****************************************************************************************



!****************************************************************************************
!DIVIDING vars_actual(2,3,4,5,6) VALUE BY UA1 (DENSITY) TO OBTAIN CONSERVATIVES VALUES
!
do is=1,n_ver

	vars_actual(2,is)         = vars_actual(2,is)/vars_actual(1,is)
    	vars_actual(3,is)         = vars_actual(3,is)/vars_actual(1,is)
    	vars_actual(5,is)         = vars_actual(5,is)/vars_actual(1,is)
    	vars_actual(6,is)         = vars_actual(6,is)/vars_actual(1,is)
         
enddo
!****************************************************************************************



!****************************************************************************************
!CALL NODAL GRADIENTS COMPUTAITON  
call gradients
!****************************************************************************************



!****************************************************************************************
!CALL ROE SOLVER
if(flux_type.eq.1) then
				
	call roeflux

else

!THIS CHECK SHOULD BE AT THE INITIALIZATION OF THE INPUT DATA BUT I PUT IT HERE BECAUSE ON 
!THE FUTURE I WILL ADD HIGHER ACCURACY SO MORE CHECKS WILL BE NEED IT
	stop 'YOU MUST CHOOSE A FLUX DISCRETIZATION SCHEME'

endif

!FOR FUTURES SCHEMES
!   if(flux_type.eq.2) call future limiter
!   if(flux_type.eq.3) call future limiter
!****************************************************************************************



!****************************************************************************************
!FOR FUTURE TURBULENCE MODEL IMPLEMENTATION
!if(iturb.ne.0) then
!
!	call turbulence model
!
!endif
!****************************************************************************************



!****************************************************************************************
!UPDATE VALUES
!
	do is=1,n_ver

		vars_actual(2,is)         = vars_actual(2,is)*vars_actual(1,is)
          	vars_actual(3,is)         = vars_actual(3,is)*vars_actual(1,is)
          	vars_actual(5,is)         = vars_actual(5,is)*vars_actual(1,is)
          	vars_actual(6,is)         = vars_actual(6,is)*vars_actual(1,is)

	enddo  
!****************************************************************************************



!****************************************************************************************
!CALL GRAVITY EFFECTS FOR FUTURE IMPLEMENTATION SOURCE TERMS
!if(gravity.ne.0) then
!
!	call gravity
!
!endif
!****************************************************************************************



!****************************************************************************************
!CALL CONVECTIVE FLUXES FOR BOUNDARY CONDITIONS (BOUNDARY CONDITIONS TREATMENT)
if(flux_type.ne.0) then

	call convective_fluxes

endif
!****************************************************************************************



!****************************************************************************************
!UPDATING PHYSICAL SOLUTION
!
do is =1,n_ver

	var_temp	= array_delta_time(is)/area_cv_mod(is)

	do ivar=1,num_var

		vars_actual(ivar,is)  = vars_prev(ivar,is) + alpha(ialpha)*var_temp*convar_exchange(ivar,is)

	enddo

enddo
!****************************************************************************************



!****************************************************************************************
!UPDATE TURBULENCE VARIABLES FOR THE TIME BEING THEY ARE EMPTY NOT YET IMPLEMENTED
!
do is=1,n_ver

	vars_actual(5,is)  = abs(vars_actual(5,is))
	vars_actual(6,is)  = abs(vars_actual(6,is))

enddo
!****************************************************************************************



end subroutine explicit_scheme
