!FILE       :	gradients.f90
!UNIT NAME  :	gradients	(SUBROUTINE)
!DESCRIPTION:	This subroutine computes nodal gradients
!		Written by Joel GUERRERO on
!		REV01-01/2007
!		Email: joegi.geo@yahoo.com

subroutine gradients


use shared_data

implicit none





!****************************************************************************************
!LOCAL VARIABLES DECLARATION
!
real,dimension(3)::d_xx						!DUMMY VARIABLES
real,dimension(3)::d_yy						!DUMMY VARIABLES
real,dimension(4)::dx_grad_tmp				!DUMMY VARIABLES
real,dimension(4)::dy_grad_tmp				!DUMMY VARIABLES
real,dimension(4,3)::sol_ver				!SOLUTION ON VERTICES
!real,dimension(2)::um(2)					!DUMMY VARIABLES			!CANDIDATE FOR DELETETION
real,dimension(3)::int_ener(3)				!DUMMY VARIABLES
!
!ATTENTION: ALL DUMMY VARIABLES DECLARED AS LOCAL VARIABLES ARE TEMPORAL
!THEY ARE ONLY USED WITHIN THE SUBROUTINE
!****************************************************************************************



!****************************************************************************************
!INITIALIZING VARIABLES
!
cons_inv6         = 1.0/6.0					!SOME CONS USED AROUND
!cons_inv3        = 1.0/3.0					!SOME CONS USED AROUND		*** CANDIDATE FOR DELETION
!cons_inv4_3      = 1.0/4.0/3.0			!SOME CONS USED AROUND		*** CANDIDATE FOR DELETION
gampr             = gam/pr					!ANOTHER GAMMA DEFINITION
gamprt            = gam/prt					!ANOTHER GAMMA DEFINITION
!cmu              = 0.09					!SOME CONS USED AROUND FOR TURBULENCE AND SUTHERLAND NT YET IMPLEMENTED
!cep              = 1.0/1.3				!SOME CONS USED AROUND FOR TURBULENCE AND SUTHERLAND NT YET IMPLEMENTED

do is=1,n_ver

	dx_grad(1,is)       = 0.0
    dx_grad(2,is)       = 0.0
    dx_grad(3,is)       = 0.0
    dx_grad(4,is)       = 0.0
    dy_grad(1,is)       = 0.0
    dy_grad(2,is)       = 0.0
    dy_grad(3,is)       = 0.0
    dy_grad(4,is)       = 0.0

enddo
!****************************************************************************************



!****************************************************************************************
!LOOP ON GLOBAL LIST TRIANGLES
!
outer_loop1:do jt=1,n_ele

!GETTING PHYSICAL SOLUTION FOR THE THREE VERTICES
         connectemp_1       = connectivity(1,jt)
         connectemp_2       = connectivity(2,jt)
         connectemp_3       = connectivity(3,jt)

         sol_ver(1,1)       = vars_actual(1,connectemp_1)
         sol_ver(2,1)       = vars_actual(2,connectemp_1)
         sol_ver(3,1)       = vars_actual(3,connectemp_1)
         sol_ver(4,1)       = pres(connectemp_1)

         sol_ver(1,2)       = vars_actual(1,connectemp_2)
         sol_ver(2,2)       = vars_actual(2,connectemp_2)
         sol_ver(3,2)       = vars_actual(3,connectemp_2)
         sol_ver(4,2)       = pres(connectemp_2)

         sol_ver(1,3)       = vars_actual(1,connectemp_3)
         sol_ver(2,3)       = vars_actual(2,connectemp_3)
         sol_ver(3,3)       = vars_actual(3,connectemp_3)
         sol_ver(4,3)       = pres(connectemp_3)

!SPECIFIC INTERNAL ENERGY
         int_ener(1)        = gam4*sol_ver(4,1)/sol_ver(1,1)
         int_ener(2)        = gam4*sol_ver(4,2)/sol_ver(1,2)
         int_ener(3)        = gam4*sol_ver(4,3)/sol_ver(1,3)

!COMPUTATION OF GRADIENS P1
         x1             = coor(1,connectemp_1)
         y1             = coor(2,connectemp_1)
         x2             = coor(1,connectemp_2)
         y2             = coor(2,connectemp_2)
         x3             = coor(1,connectemp_3)
         y3             = coor(2,connectemp_3)

         d_xx(1)        = y2 - y3
         d_xx(2)        = y3 - y1
         d_xx(3)        = y1 - y2
         d_yy(1)        = x3 - x2
         d_yy(2)        = x1 - x3
         d_yy(3)        = x2 - x1
               
			     
         do k=1,4

            dx_grad_tmp(k)      = sol_ver(k,1)*d_xx(1) + sol_ver(k,2)*d_xx(2) + sol_ver(k,3)*d_xx(3)

            dy_grad_tmp(k)      = sol_ver(k,1)*d_yy(1) + sol_ver(k,2)*d_yy(2) + sol_ver(k,3)*d_yy(3)

		 enddo


         dx_grad(1,connectemp_1)    = dx_grad(1,connectemp_1) + dx_grad_tmp(1)
         dx_grad(1,connectemp_2)    = dx_grad(1,connectemp_2) + dx_grad_tmp(1)
         dx_grad(1,connectemp_3)    = dx_grad(1,connectemp_3) + dx_grad_tmp(1)
         dx_grad(2,connectemp_1)    = dx_grad(2,connectemp_1) + dx_grad_tmp(2)
         dx_grad(2,connectemp_2)    = dx_grad(2,connectemp_2) + dx_grad_tmp(2)
         dx_grad(2,connectemp_3)    = dx_grad(2,connectemp_3) + dx_grad_tmp(2)
         dx_grad(3,connectemp_1)    = dx_grad(3,connectemp_1) + dx_grad_tmp(3)
         dx_grad(3,connectemp_2)    = dx_grad(3,connectemp_2) + dx_grad_tmp(3)
         dx_grad(3,connectemp_3)    = dx_grad(3,connectemp_3) + dx_grad_tmp(3)
         dx_grad(4,connectemp_1)    = dx_grad(4,connectemp_1) + dx_grad_tmp(4)
         dx_grad(4,connectemp_2)    = dx_grad(4,connectemp_2) + dx_grad_tmp(4)
         dx_grad(4,connectemp_3)    = dx_grad(4,connectemp_3) + dx_grad_tmp(4)

         dy_grad(1,connectemp_1)    = dy_grad(1,connectemp_1) + dy_grad_tmp(1)
         dy_grad(1,connectemp_2)    = dy_grad(1,connectemp_2) + dy_grad_tmp(1)
         dy_grad(1,connectemp_3)    = dy_grad(1,connectemp_3) + dy_grad_tmp(1)
         dy_grad(2,connectemp_1)    = dy_grad(2,connectemp_1) + dy_grad_tmp(2)
         dy_grad(2,connectemp_2)    = dy_grad(2,connectemp_2) + dy_grad_tmp(2)
         dy_grad(2,connectemp_3)    = dy_grad(2,connectemp_3) + dy_grad_tmp(2)
         dy_grad(3,connectemp_1)    = dy_grad(3,connectemp_1) + dy_grad_tmp(3)
         dy_grad(3,connectemp_2)    = dy_grad(3,connectemp_2) + dy_grad_tmp(3)
         dy_grad(3,connectemp_3)    = dy_grad(3,connectemp_3) + dy_grad_tmp(3)
         dy_grad(4,connectemp_1)    = dy_grad(4,connectemp_1) + dy_grad_tmp(4)
         dy_grad(4,connectemp_2)    = dy_grad(4,connectemp_2) + dy_grad_tmp(4)
         dy_grad(4,connectemp_3)    = dy_grad(4,connectemp_3) + dy_grad_tmp(4)

enddo outer_loop1
!****************************************************************************************



!****************************************************************************************
!FINAL COMPUTATION OF NODAL GRADIENTS
!
do is=1,n_ver

	ais					= cons_inv6/area_cv(is)
    dx_grad(1,is)       = dx_grad(1,is)*ais
    dx_grad(2,is)       = dx_grad(2,is)*ais
    dx_grad(3,is)       = dx_grad(3,is)*ais
    dx_grad(4,is)       = dx_grad(4,is)*ais
    dy_grad(1,is)       = dy_grad(1,is)*ais
    dy_grad(2,is)       = dy_grad(2,is)*ais
    dy_grad(3,is)       = dy_grad(3,is)*ais
    dy_grad(4,is)       = dy_grad(4,is)*ais

enddo
!****************************************************************************************



end subroutine gradients
