!FILE       :	init_guess.f90
!UNIT NAME  :	init_guess	(SUBROUTINE)
!DESCRIPTION:	This subroutine set the initial guess for the whole domain
!		It uses perfect gas isentropic relation for initial guess computation
!		This is highly optimize for compressible flows (MACH > 0.1)
!		Use with extremely care with mach numbers below 0.1
!		Written by Joel GUERRERO
!		REV01-01/2007
!		Email: joegi.geo@yahoo.com

subroutine init_guess


use shared_data

implicit none





!****************************************************************************************
!INITIAL GUESS - FREE STREAM
!
pres_in     	= 1.0/(gam*in_mach**2)
temp_init	= 1.0/(gam*gam1*in_mach*in_mach)

rho_in	    	= 1.0
teta		= air_incidence_angle*3.14156/180.0

velxin		= 1*cos(teta)
velyin		= 1*sin(teta)
momxin		= rho_in*velxin
momyin		= rho_in*velyin

ener_in		= 0.5*rho_in*(velxin*velxin+velyin*velyin)+pres_in/gam1
rho_out		= rho_in
velxout		= velxin
velyout		= velyin
momxout		= momxin
momyout		= momyin

pres_out    	= pres_in*pres_ratio
ener_out    	= 0.5*rho_out*(velxout**2+velyout**2)+pres_out/gam1

!xkin	= 0				!TO BE SET FOR FUTURE DEVELOPMENTS - TURBULENCE
!xein	= 0				!TO BE SET FOR FUTURE DEVELOPMENTS - TURBULENCE
!****************************************************************************************



end subroutine init_guess
