!FILE       :	roeflux.f90
!UNIT NAME  :	roeflux (SUBROUTINE)
!DESCRIPTION:	This subroutine computes convective fluxes using roe approximate riemann solver
!		This is an adaptation of the code Higher order Godunov-type "generic" 2D scheme 
!		from andrei_chernousov.  
!		http://www.geocities.com/andrei_chernousov/freecfd.htm
!		http://www.geocities.ws/MotorCity/Pit/9939/freecfd.htm
!		written by Joel GUERRERO 
!		REV02-05/2007
!		Email: joegi.geo@yahoo.com

subroutine roeflux


use shared_data

implicit none





!****************************************************************************************
!LOCAL VARIABLES DEFINITION
!
integer::nsg
!real::invas1
real,dimension(4)::dpm					!DUMMY VARIABLES
real,dimension(4)::dpor					!DUMMY VARIABLES
real,dimension(4)::dpex					!DUMMY VARIABLES
real,dimension(4)::aux1					!DUMMY VARIABLES
real,dimension(4)::aux2					!DUMMY VARIABLES
real,dimension(4)::gradi				!DUMMY VARIABLES
real,dimension(4)::gradj				!DUMMY VARIABLES
!
!ATTENTION: ALL DUMMY VARIABLES DECLARED AS LOCAL VARIABLES ARE TEMPORAL
!THEY ARE ONLY USED WITHIN THE SUBROUTINE
!****************************************************************************************



!****************************************************************************************
!LOCAL VARIABLES INITIALIZATION
!
usgam1=1.0/gam1
gsgam1=gam/gam1
	       
beta2 = beta0					!FOR SECOND ORDER ACCURACY
beta3 = 0.5*(1.0 - 2.0*beta0)			!FOR SECOND ORDER ACCURACY

if(sch_order.eq.2) then

      beta2 = 2.0*beta0				!FOR SECOND ORDER ACCURACY MOD
      beta3 = 1.0 - 2.0*beta0			!FOR SECOND ORDER ACCURACY MOD
 
endif

e2 = 1.e-16
!****************************************************************************************



!****************************************************************************************
!Loop on global list of edges
!
outer_loop1:do nsg=1,real_nedg 


!Local indexing of the vertices of the current edge
    connectemp_1     = edg_connec(1,nsg)
    connectemp_2     = edg_connec(2,nsg)


    aix       = coor(1,connectemp_2)-coor(1,connectemp_1)
    aiy       = coor(2,connectemp_2)-coor(2,connectemp_1) 


!assignation rediction on vertices physical states
    uas11     = vars_actual(1,connectemp_1)
    uas21     = vars_actual(2,connectemp_1)
    uas31     = vars_actual(3,connectemp_1)
    uas41     = pres(connectemp_1)
    uas12     = vars_actual(1,connectemp_2)
    uas22     = vars_actual(2,connectemp_2)
    uas32     = vars_actual(3,connectemp_2)
    uas42     = pres(connectemp_2)



!****************************************************************************************
!
if1:if(sch_order.eq.1) then

	call comp_in_roe(nsg)

else


	gradi(1)  = beta2*(aix*dx_grad(1,connectemp_1) + aiy*dy_grad(1,connectemp_1)) + beta3*(uas12 - uas11)

	gradi(2)  = beta2*(aix*dx_grad(2,connectemp_1) + aiy*dy_grad(2,connectemp_1)) + beta3*(uas22 - uas21)

	gradi(3)  = beta2*(aix*dx_grad(3,connectemp_1) + aiy*dy_grad(3,connectemp_1)) + beta3*(uas32 - uas31)

    	gradi(4)  = beta2*(aix*dx_grad(4,connectemp_1) + aiy*dy_grad(4,connectemp_1)) + beta3*(uas42 - uas41)

    	gradj(1)  = beta2*(aix*dx_grad(1,connectemp_2) + aiy*dy_grad(1,connectemp_2)) + beta3*(uas12 - uas11)

    	gradj(2)  = beta2*(aix*dx_grad(2,connectemp_2) + aiy*dy_grad(2,connectemp_2)) + beta3*(uas22 - uas21)

    	gradj(3)  = beta2*(aix*dx_grad(3,connectemp_2) + aiy*dy_grad(3,connectemp_2)) + beta3*(uas32 - uas31)

    	gradj(4)  = beta2*(aix*dx_grad(4,connectemp_2) + aiy*dy_grad(4,connectemp_2)) + beta3*(uas42 - uas41)



	if2:if(sch_order.eq.2) then

			uas11     = uas11 + 0.5*gradi(1)
			uas21     = uas21 + 0.5*gradi(2)
			uas31     = uas31 + 0.5*gradi(3)
			uas41     = uas41 + 0.5*gradi(4)

			uas12     = uas12 - 0.5*gradj(1)
			uas22     = uas22 - 0.5*gradj(2)
			uas32     = uas32 - 0.5*gradj(3)
			uas42     = uas42 - 0.5*gradj(4)



!*********************************************************************************************************
!*********************************************************************************************************
!*********************************************************************************************************
!SLOPE LIMITER IMPLEMENTED HERE
!*********************************************************************************************************

         elseif(sch_order.eq.3) then
!***************
         dpm(1)    =	-(uas12 - uas11)
         dpex(1)   =	-4.0*gradi(1) - dpm(1)
         aux1(1)   = 	0.25*(1.0+  SIGN(1.0, dpex(1)*dpm(1)))
         dpor(1)   =	-4.0*gradj(1) - dpm(1)
         aux2(1)   = 	0.25*(1.0 + SIGN(1.0, dpor(1)*dpm(1)))
!***************
         dpm(2)    =	-(uas22 - uas21)
         dpex(2)   =	-4.0*gradi(2) - dpm(2)
         aux1(2)   = 	0.25*(1.0 + SIGN(1.0, dpex(2)*dpm(2)))
         dpor(2)   =	-4.0*gradj(2) - dpm(2)
         aux2(2)   = 	0.25*(1.0 + SIGN(1.0, dpor(2)*dpm(2)))
!***************
         dpm(3)    =	-(uas32 - uas31)
         dpex(3)   =	-4.0*gradi(3) - dpm(3)
         aux1(3)   = 	0.25*(1.0 + SIGN(1.0, dpex(3)*dpm(3)))
         dpor(3)   =	-4.0*gradj(3) - dpm(3)
         aux2(3)   = 	0.25*(1.0 + SIGN(1.0, dpor(3)*dpm(3)))
!***************
         dpm(4)    =	-(uas42 - uas41)
         dpex(4)   =	-4.0*gradi(4) - dpm(4)
         aux1(4)   = 	0.25*(1.0 + SIGN(1.0, dpex(4)*dpm(4)))
         dpor(4)   =	-4.0*gradj(4) - dpm(4)
         aux2(4)   = 	0.25*(1.0 + SIGN(1.0, dpor(4)*dpm(4)))
!***************
         gradi(1)  = 	aux1(1)*((dpex(1)*dpex(1) + e2)*dpm(1)+(dpm(1)*dpm(1)   &
			+ e2)*dpex(1))/(dpex(1)*dpex(1)  + dpm(1)*dpm(1) + 2.0*e2)

         gradj(1)  = 	aux2(1)*((dpor(1)*dpor(1) + e2)*dpm(1)+(dpm(1)*dpm(1)   &
			+ e2)*dpor(1))/(dpor(1)*dpor(1)  + dpm(1)*dpm(1) + 2.0*e2)
!***************
         gradi(2)  = 	aux1(2)*((dpex(2)*dpex(2) + e2)*dpm(2)+(dpm(2)*dpm(2)   &
			+ e2)*dpex(2))/(dpex(2)*dpex(2)  + dpm(2)*dpm(2) + 2.0*e2)

         gradj(2)  = 	aux2(2)*((dpor(2)*dpor(2) + e2)*dpm(2)+(dpm(2)*dpm(2)   &
			+ e2)*dpor(2))/(dpor(2)*dpor(2)  + dpm(2)*dpm(2) + 2.0*e2)

         gradi(3)  = 	aux1(3)*((dpex(3)*dpex(3) + e2)*dpm(3)+(dpm(3)*dpm(3)   &
			+ e2)*dpex(3))/(dpex(3)*dpex(3)  + dpm(3)*dpm(3) + 2.0*e2)

         gradj(3)  = 	aux2(3)*((dpor(3)*dpor(3) + e2)*dpm(3)+(dpm(3)*dpm(3)   &
			+ e2)*dpor(3))/(dpor(3)*dpor(3)  + dpm(3)*dpm(3) + 2.0*e2)
!***************
         gradi(4)  = 	aux1(4)*((dpex(4)*dpex(4) + e2)*dpm(4)+(dpm(4)*dpm(4)   &
			+ e2)*dpex(4))/(dpex(4)*dpex(4)  + dpm(4)*dpm(4) + 2.0*e2)

         gradj(4)  = 	aux2(4)*((dpor(4)*dpor(4) + e2)*dpm(4)+(dpm(4)*dpm(4)   &
			+ e2)*dpor(4))/(dpor(4)*dpor(4)  + dpm(4)*dpm(4) + 2.0*e2)
!***************
         uas11     = uas11 - gradi(1)
         uas21     = uas21 - gradi(2)
         uas31     = uas31 - gradi(3)
         uas41     = uas41 - gradi(4)
!***************
         uas12     = uas12 + gradj(1)
         uas22     = uas22 + gradj(2)
         uas32     = uas32 + gradj(3)
         uas42     = uas42 + gradj(4)

!*********************************************************************************************************
!SLOPE LIMITER IMPLEMENTED HERE END
!*********************************************************************************************************
!*********************************************************************************************************
!*********************************************************************************************************



!THIS CHECK SHOULD BE AT THE INITIALIZATION OF THE INPUT DATA BUT I PUT IT HERE BECAUSE ON 
!THE FUTURE I WILL ADD HIGHER ACCURACY SO MORE CHECKS WILL BE NEED IT
!		elseif(sch_order.ne.1.or.sch_order.ne.2) then

!			print *, 'YOU MUST CHOOSE THE SCHEME ORDER IN THE INPUT FILE'
!			print *, '1 FOR FIRST ORDER ACCURACY OR 2 FOR SECOND ORDER ACCURACY'
!			print *
!			stop ' ABNORMAL EXECUTION'

	endif if2


endif if1


call comp_in_roe(nsg)


enddo outer_loop1
!****************************************************************************************



end subroutine roeflux





!****************************************************************************************
!****************************************************************************************
!****************************************************************************************
!****************************************************************************************
!****************************************************************************************
!****************************************************************************************
!****************************************************************************************
!****************************************************************************************
!****************************************************************************************
!FILE       :	roeflux.f90
!UNIT NAME  :	comp_in_roe (SUBROUTINE)
!DESCRIPTION:	This subroutine computes convective fluxes using roe approximte riemann solver
!		This subroutine is call within roeflux to do some computations
!		Written by Joel GUERRERO on 
!		REV01-01/2007
!		Email: joegi.geo@yahoo.com

subroutine comp_in_roe(nsg)

use shared_data

implicit none

!****************************************************************************************
!LOCAL VARIABLES DEFINITION
!
integer::nsg
real::invas1
!
!ATTENTION: ALL DUMMY VARIABLES DECLARED AS LOCAL VARIABLES ARE TEMPORAL
!THEY ARE ONLY USED WITHIN THE SUBROUTINE
!****************************************************************************************



!****************************************************************************************
!LOCAL VARIABLES INITIALIZATION
!
usgam1=1.0/gam1
gsgam1=gam/gam1
	       
beta2 = beta0					!FOR SECOND ORDER ACCURACY
beta3 = 0.5*(1.0 - 2.0*beta0)			!FOR SECOND ORDER ACCURACY

if(sch_order.eq.2) then

      beta2 = 2.0*beta0				!FOR SECOND ORDER ACCURACY MOD
      beta3 = 1.0 - 2.0*beta0			!FOR SECOND ORDER ACCURACY MOD
 
 endif

e2 = 1.e-16
!****************************************************************************************


!****************************************************************************************
!
	invas1    = 1.0/uas11

    	dua1      = sqrt(uas11)
    	dua2      = sqrt(uas12)
    	dua3      = 1.0/(dua1 + dua2)
!****************************************************************************************



!****************************************************************************************
!Enthalpy
!
	h1        = gsgam1*uas41*invas1 + 0.5*(uas21*uas21 + uas31*uas31)
    	h2        = gsgam1*uas42/uas12  + 0.5*(uas22*uas22 + uas32*uas32)
!****************************************************************************************



!****************************************************************************************
!Roe's mean values computation
!
	ucent     = (uas21*dua1 + uas22*dua2)*dua3
    	vcent     = (uas31*dua1 + uas32*dua2)*dua3
    	hcent     = (h1*dua1 + h2*dua2)*dua3
    	uvnc      = 0.5*(ucent*ucent + vcent*vcent)
    	ccent     = sqrt(abs(gam1*(hcent-uvnc)))
    	invcnt    = 1.0/ccent

    	pres1     = uas41 
    	uas41     = usgam1*uas41 + 0.5*uas11* (uas21*uas21 + uas31*uas31)
    	uas42     = usgam1*uas42 + 0.5*uas12* (uas22*uas22 + uas32*uas32)
    	uas21     = uas21*uas11
    	uas22     = uas22*uas12
    	uas31     = uas31*uas11
    	uas32     = uas32*uas12

    	dua1      = uas12 - uas11
    	dua2      = uas22 - uas21
    	dua3      = uas32 - uas31
    	dua4      = uas42 - uas41
!****************************************************************************************



!****************************************************************************************
!Eigenvalues computation
!
	xnn       = cv_normals(1,nsg)
    	ynn       = cv_normals(2,nsg)
    	rnn       = cv_normals(3,nsg)

    	vp1       = rnn*(xnn*ucent + ynn*vcent)
    	vp3       = vp1 + ccent*rnn
    	vp4       = vp1 - ccent*rnn
    	uq41      = uvnc*invcnt + usgam1*ccent
    	uq42      = xnn*ucent + ynn*vcent
    	rc1       = gam1*invcnt
    	rc2       = rc1*invcnt
!****************************************************************************************



!****************************************************************************************
!Computation of the centered part of the flux
!
	flu11     = rnn*(xnn*uas21 + ynn*uas31)
    	flu21     = xnn*rnn*pres1 + flu11*uas21*invas1
    	flu31     = ynn*rnn*pres1 + flu11*uas31*invas1
    	flu41     = h1*flu11
!****************************************************************************************



!****************************************************************************************
!Computation of the diffusive part of the flux
!

	!duv1      = 0
	!duv2      = 0 
	!duv3      = 0
	!duv4      = 0


	fdc1      = 	max(vp1,0.0)*(dua1 + rc2*(-uvnc*dua1 + ucent*dua2 + vcent*dua3 - dua4)) 

	fdc2      = 	max(vp1,0.0)*((xnn*vcent - ynn*ucent)*dua1 + ynn*dua2 - xnn*dua3)

	fdc3      = 	max(vp3,0.0)*(0.5*(-uq42*dua1 + xnn*dua2 + ynn*dua3) + 0.5*rc1*(uvnc*dua1 &
			- ucent*dua2 - vcent*dua3 + dua4))

	fdc4      = 	max(vp4,0.0)*(0.5*( uq42*dua1 - xnn*dua2 - ynn*dua3) + 0.5*rc1*(uvnc*dua1 &
			- ucent*dua2 - vcent*dua3 + dua4))   


	duv1      = 	fdc1 + (fdc3 + fdc4)*invcnt

	duv2      = 	ucent*fdc1 + ynn*fdc2 + (ucent*invcnt + xnn)*fdc3 + (ucent*invcnt - xnn)*fdc4

	duv3      = 	vcent*fdc1 - xnn*fdc2 + (vcent*invcnt + ynn)*fdc3 + (vcent*invcnt - ynn)*fdc4

	duv4      = 	uvnc*fdc1 + (ynn*ucent - xnn*vcent)* fdc2 + (uq41+uq42)*fdc3 + (uq41-uq42)*fdc4
!****************************************************************************************



!****************************************************************************************
!Gathering of the elementary fluxes into the global ones 
!

!	flu_turb(nsg)=flu11+duv1					!FOR FUTURE TURBULENCE MODEL IMPLEMENTATION - NOT YET USED FOR TURBULENCE USED

    	convar_exchange(1,connectemp_1)    = convar_exchange(1,connectemp_1) + flu11 + duv1
    	convar_exchange(2,connectemp_1)    = convar_exchange(2,connectemp_1) + flu21 + duv2
    	convar_exchange(3,connectemp_1)    = convar_exchange(3,connectemp_1) + flu31 + duv3
    	convar_exchange(4,connectemp_1)    = convar_exchange(4,connectemp_1) + flu41 + duv4

    	convar_exchange(1,connectemp_2)    = convar_exchange(1,connectemp_2) - flu11 - duv1
    	convar_exchange(2,connectemp_2)    = convar_exchange(2,connectemp_2) - flu21 - duv2
    	convar_exchange(3,connectemp_2)    = convar_exchange(3,connectemp_2) - flu31 - duv3
    	convar_exchange(4,connectemp_2)    = convar_exchange(4,connectemp_2) - flu41 - duv4
!****************************************************************************************


end subroutine comp_in_roe
!****************************************************************************************
!****************************************************************************************
!****************************************************************************************
!****************************************************************************************
!****************************************************************************************
!****************************************************************************************
!****************************************************************************************
!****************************************************************************************
!****************************************************************************************
