!FILE       :	screen_control.f90
!UNIT NAME  :	screen_control	(SUBROUTINE)
!DESCRIPTION:	This subroutine dump data to screen in order to monitor the execution
!		Also output file EULER_SOL is saved for restarting purposes
!		Written by Joel GUERRERO
!		REV01-01/2007
!		Email: joegi.geo@yahoo.com

subroutine screen_control


use shared_data

implicit none





!****************************************************************************************
!SAVING SOLUTION ON FILE INIT FOR RESTARTING PURPOSES
!
open(10,file="EULER_SOL",status="unknown")
rewind(10)

do is=1,n_ver

      write(10,*)(vars_actual(i,is),i=1,4)

enddo

write(10,*) iter_actual,time_actual

close(10)
!****************************************************************************************



!****************************************************************************************
		
		print *
		write(95,*)
		print 10,time_actual,delta_time
		write(95,10) time_actual,delta_time
10		format( '    Physical time (time_actual)    = ',f10.4, &
		/,'    Minimal time step (delta_time) = ',e15.8)
!****************************************************************************************



!****************************************************************************************
!VALUES INITIALIZATION
!
np_supersonic				= 0
max_mach				= 0.0
min_mach				= 1.0e+8
min_pres				= 1.0e+8
max_pres				= 0.0
min_rho					= 1.0e+8
max_rho					= 0.0
velxmin					= 1.0e+8
velxmax					=-1.0e+8
velymin					= 1.0e+8
velymax					=-1.0e+8
xkmin					= 1.0e+8
xkmax					=-1.0e+8
xemin					= 1.0e+8
xemax					=-1.0e+8
tempemin				= 1.0e+8
tempemax				=-1.0e+8
!****************************************************************************************



!**************************************************************************************** 
!VALUES MAX AND MIN COMPUTATION
!
do is=1,n_ver

    local_u			= vars_actual(2,is)/vars_actual(1,is)
    local_v			= vars_actual(3,is)/vars_actual(1,is)
    local_uv			= sqrt(local_u*local_u + local_v*local_v)
    local_pp			= pres(is)
    temperature			= local_pp/(gam1*vars_actual(1,is))
    speed_sound			= sqrt(gam*local_pp/vars_actual(1,is))
    local_mach			= local_uv/speed_sound
    max_mach			= max(max_mach, local_mach)
    min_mach			= min(min_mach, local_mach)
    velxmin			= min(velxmin , local_u)
    velxmax			= max(velxmax , local_u)
    velymin			= min(velymin , local_v)
    velymax			= max(velymax , local_v)
    min_pres			= min(min_pres , pres(is))
    max_pres			= max(max_pres , pres(is))
    min_rho			= min(min_rho , vars_actual(1,is))
    max_rho			= max(max_rho , vars_actual(1,is))
!   tempemin			= min(tempemin , temp)
!   tempemax			= max(tempemax , temp)
    tempemin			= min(tempemin , temperature)
    tempemax			= max(tempemax , temperature)
    xkmin			= min(xkmin , vars_actual(5,is))
    xkmax			= max(xkmax , vars_actual(5,is))
    xemin			= min(xemin , vars_actual(6,is))
    xemax			= max(xemax , vars_actual(6,is))

    if (local_mach.gt.1.0) then

			np_supersonic = np_supersonic+1

	endif

enddo
!****************************************************************************************



!**************************************************************************************** 
!SCREEN OUTPUT
!   
	print 998,np_supersonic
	write(95,998) np_supersonic
    	print 1000,max_mach,min_mach,max_pres,min_pres,max_rho,min_rho,velxmax,velxmin,velymax,velymin
	write(95,1000) max_mach,min_mach,max_pres,min_pres,max_rho,min_rho,velxmax,velxmin,velymax,velymin
!	print *,max_mach,min_mach,max_pres,min_pres,max_rho,min_rho,velxmax,velxmin,velymax,velymin,tempemin,tempemax
!	print *,'*********************************************'
!	print *

998   format('    Number of supersonic points    = ',i4)
1000  format(/ &
          , '    Maximum mach number            = ', e15.8,/ &
          , '    Minimum mach number            = ', e15.8,/ &
          , '    Maximum pressure               = ', e15.8,/ &
          , '    Minimum pressure               = ', e15.8,/ &
          , '    Maximum density                = ', e15.8,/ &
          , '    Minimum density                = ', e15.8,/ &
          , '    Maximum x-velocity             = ', e15.8,/ &
          , '    Minimum x-velocity             = ', e15.8,/ &
          , '    Maximum y-velocity             = ', e15.8,/ &
          , '    Minimum y-velocity             = ', e15.8,/)

!THIS IS FOR FUTURE EXTENSION OF TURBULENCE MODELS
!1001   format(/ &
!          , '    Maximum k                      = ', e15.8,/ &
!          , '    Minimum k                      = ', e15.8,/ &
!          , '    Maximum epsilon                = ', e15.8,/ &
!          , '    Minimum epsilon                = ', e15.8,/)
!****************************************************************************************



end subroutine screen_control
