!FILE       :	shared_data_module.f90
!UNIT NAME  :	shared_data	(MODULE)
!DESCRIPTION:	In this module all the global variables are initialized
!		Written by Joel GUERRERO 
!		REV01-01/2007
!		Email: joegi.geo@yahoo.com

module shared_data


implicit none





!==========================================================================================
!ATTENTION: ALL DUMMY VARIABLES DECLARED HERE ARE JUST OF TEMPORAL USED THEY ARE NOT
!			RELATED TO MEANINGFUL VALUES -JUST FOR TEMPORAL COMPUTATIONS-
!==========================================================================================

!****************************************************************************************
!COUNTERS AND DUMMY VARIABLES
!****************************************************************************************
integer::i,j,k,index,jt,kv,is,ifr,ivar,it,ialpha			!COUNTERS

real::sum								!ACTUAL  SUMATION FOR CONVERGENCE CHECK
real::sum_prev								!INITIAL SUMATION FOR CONVERGENCE CHECK

real::temp								!temporal value  candidate for deletion
!****************************************************************************************



!****************************************************************************************
!TIMMING VARIABLES
!****************************************************************************************
!integer::						!COUNTERS

real::time_begin,time_begin_iter			!time begin var
real::time_end,time_end_iter				!time end var

!****************************************************************************************



!****************************************************************************************
!INITIALIZATION OF SOME VARIABLES AND SOLVER PARAMETERS
!****************************************************************************************
!PERFECT GAS CONS. 
real::gam     
real::gam1    
real::gam4    
!PERFECT GAS CONS.


!PRANDTL NUMBER
real::pr      
real::prt 
!PRANDTL NUMBER

!RUNGE KUTTA PARAMETERS
integer::irk=4

real,dimension(4)::alpha

real::beta0
real::beta1
real::beta2
real::beta3
!RUNGE KUTTA PARAMETERS

!****************************************************************************************
   


!****************************************************************************************
!READ DATA
!****************************************************************************************
real::in_mach					!inlet mach number
real::pres_ratio				!pressure ratio in/out
real::air_incidence_angle			!air incidence angle
real::cfl					!cfl number
real::time_max					!maximum physical time
real::residual					!minimum residual

integer::save_frec		!iteration saving frecuency
integer::flux_type		!flux type 1=roe
integer::sch_order		!scheme order 1=first  2=second
integer::time_type		!steady/unsteady 1=unsteady 2=steady (local time stepping)
integer::restart		!new solution/continue from old 1=new 2=old
integer::iter_max		!maximum number of iteration
integer::iter_max_in		!maximum number of iteration this is the original value form the data file
integer::domain			!NULL
integer::vis_type		!NULL
integer::turb_type		!NULL
!integer::walllaw		!NULL		FUTURE EXTENSION
!integer::suthertype		!NULL		FUTURE EXTENSION
!****************************************************************************************



!****************************************************************************************
!INITIAL GUESS - FREE STREAM
!****************************************************************************************
real::pres_in		!pressure in  
real::temp_init		!temperature initial
real::rho_in		!density in
real::teta		!angle of incidence/of attack converted
real::velxin		!velocity in u
real::velyin		!velocity in v
real::momxin		!momentum in rho*u
real::momyin		!momentum in rho*v
real::ener_in		!energy in   
real::rho_out		!density out
real::velxout		!velocity out u
real::velyout		!velocity out v
real::momxout		!momentum out rho*u
real::momyout		!momentum out rho*v 
real::pres_out		!pressure out   
real::ener_out		!energy out

real::xkin		!for k-e		FUTURE EXTENSION
real::xein		!for k-e		FUTURE EXTENSION
!****************************************************************************************



!****************************************************************************************
!MESH DATA
!n_ means number
!num_ means number
!coor means coordinates
!****************************************************************************************
integer::n_ver			!number of vertices
integer::n_ele			!number of elements
integer::max_ele		!maximum number of elements   **** CANDIDATE FOR DELETETION CAN BE CHANGED THIS WITHIN THE SOFT TO n_ele
integer::max_edges		!maximum number od edges

real,allocatable,dimension(:,:)::coor		!vertex coordinates array

integer,allocatable,dimension(:,:)::connectivity				!connectivity array
integer,allocatable,dimension(:)::array_boundary_ver				!array of boundary flags
integer,allocatable,dimension(:)::array_slip_ver				!array of slipping ver
integer,allocatable,dimension(:)::array_noslip_ver				!array of noslipping ver
integer,allocatable,dimension(:)::array_outlet_ver				!array of downstream ver
integer,allocatable,dimension(:)::array_inlet_ver				!array of upstream ver
integer,allocatable,dimension(:)::array_inpro_ver				!array of inflow profile ver
integer,allocatable,dimension(:)::array_temp					!array temp

integer::num_internal_ver		
integer::num_slip_ver	
integer::num_noslip_ver		
integer::num_outlet_ver		
integer::num_inlet_ver		
integer::num_inpro_ver		
integer::num_total_ver		
integer::num_total_boundary_ver	
!****************************************************************************************



!****************************************************************************************
!ELEMENTS AREAS COMP
!cv means control volume
!****************************************************************************************
real,allocatable,dimension(:)::area_cv		!control volumenes area
real,allocatable,dimension(:)::area_ele		!triangle area
real,allocatable,dimension(:)::area_cv_mod	!control volumenes area reasignation
real,allocatable,dimension(:)::area_ele_mod	!triangle area reasignation
!****************************************************************************************



!****************************************************************************************
!ELEMENTS LENGHT COMP
!****************************************************************************************
real,allocatable,dimension(:)::array_ele_lenght		!array elements lenght
!****************************************************************************************



!****************************************************************************************
!EDGE RECONSTRUCTION
!edg means edge
!bound means boundary
!****************************************************************************************
integer,allocatable,dimension(:,:)::edg_connec	!edge connectivity
integer,allocatable,dimension(:)::bound_connec	!boundary edge list

real,allocatable,dimension(:,:)::cv_normals	!control volume normals definition
real,allocatable,dimension(:)::cv_normals_bx	!boundary normal x
real,allocatable,dimension(:)::cv_normals_by	!boundary normal y
real,allocatable,dimension(:)::cv_normals_br	!boundary normal resul

integer::real_nedg
!****************************************************************************************



!****************************************************************************************
!SOLUTION INITIALIZATION
!****************************************************************************************
real::eps							!EPSILON
real::time_actual						!ACTUAL TIME
real::time_prev							!INITIAL TIME


integer::iter_actual						!ACTUAL ITERATION
integer::iter_prev						!INITIAL ITERATION
integer::num_var						!NUMBER OF CONSERVATIVE VARIABLES

real,allocatable,dimension(:,:)::vars_prev			!ARRAY OF NEW VARIABLES
real,allocatable,dimension(:,:)::vars_actual			!ARRAY OF OLD VARIABLES
real,allocatable,dimension(:)::pres				!ARRAY OF PRESSURE
!****************************************************************************************



!****************************************************************************************
!DELTA T SIZE IN FUNCTION OF CELL SIZE AND CFL NUMBER
!****************************************************************************************
real::delta_time					!delta time
real::vel_norm						!velocity module
real::sigmax						!velocity module plus c(speed of sound)
real::cfl_viscoef					!dummy argument  CANDIDATE FOR DELETION
real::dtmin						!minimum delta time

!real::xnum						!dummy argument  CANDIDATE FOR DELETION
!real::xden						!dummy argument  CANDIDATE FOR DELETION
!real::cste						!dummy argument  CANDIDATE FOR DELETION
!real::reytot						!dummy argument  CANDIDATE FOR DELETION
!real::reynolds						!dummy argument  CANDIDATE FOR DELETION
!real::dsrey						!dummy argument  CANDIDATE FOR DELETION


!real,allocatable,dimension(:)::reylam			!dummy argument  CANDIDATE FOR DELETION OR FUTURE EXTENSION
!real,allocatable,dimension(:)::reyturb			!dummy argument  CANDIDATE FOR DELETION OR FUTURE EXTENSION
real,allocatable,dimension(:)::array_delta_time		!ARRAY OF DELTA T COMPUTE USING CFL NUMBER
!****************************************************************************************




!****************************************************************************************
!EXPLICIT SCHEME FORMULATION
!****************************************************************************************
real,allocatable,dimension(:,:)::convar_exchange	!ARRAY OF CONSERVATIVE VARIABLES FOR INFORMATION EXCHANGE
							!ON THIS ARRAY ALL THE FLUES ARE ADDED
   
real::var_temp						!DUMMY VALUE
!****************************************************************************************



!****************************************************************************************
!NODAL GRADIENTS COMPUTATION
!****************************************************************************************
real::cons_inv6						!DUMMY VALUE         
!real::cons_inv3					!DUMMY VALUE    *** CANDIDATE FOR DELETION
!real::cons_inv4_3					!DUMMY VALUE	*** CANDIDATE FOR DELETION
real::gampr						!ANOTHER GAMMA DEF
real::gamprt						!ANOTHER GAMMA DEF
!real::cmu						!DUMMY VALUE		*** NOT YET IMPLEMENTED FUTURE EXTENSION OR CANDIDATE FOR DELETION
!real::cep						!DUMMY VALUE		*** NOT YET IMPLEMENTED FUTURE EXTENSION OR CANDIDATE FOR DELETION
real::ais						!DUMMY VALUE

real::connectemp_1					!DUMMY VALUE LINKED TO CONNECTIVITY         
real::connectemp_2					!DUMMY VALUE LINKED TO CONNECTIVITY        
real::connectemp_3					!DUMMY VALUE LINKED TO CONNECTIVITY       

real::x1						!DUMMY ARGUMENT           
real::y1						!DUMMY ARGUMENT         
real::x2						!DUMMY ARGUMENT           
real::y2						!DUMMY ARGUMENT          
real::x3						!DUMMY ARGUMENT            
real::y3						!DUMMY ARGUMENT       

real,allocatable,dimension(:,:)::dx_grad		!ARRAY OF NODAL GRADIENTS	(4,NT)
real,allocatable,dimension(:,:)::dy_grad		!ARRAY OF NODAL GRADIENTS	(4,NT)
!****************************************************************************************



!****************************************************************************************
!ROE FLUXES
!****************************************************************************************
!HERE ALL THESE VALUES ARE PASSED TO CE VARIABLE DECLARE ON EXPLICIT SCHEME
!
real::usgam1					!DUMMY VALUE		!ANOTHER GAMMA DEFINITION
real::gsgam1					!DUMMY VALUE		!ANOTHER GAMMA DEFINITION
real::e2					!DUMMY VALUE		!SMALL VALUE
real::aix					!DUMMY VALUE 
real::aiy					!DUMMY VALUE 

real::uas11					!DUMMY VALUE 
real::uas21					!DUMMY VALUE 
real::uas31					!DUMMY VALUE 
real::uas41					!DUMMY VALUE 

real::uas12					!DUMMY VALUE 
real::uas22					!DUMMY VALUE 
real::uas32					!DUMMY VALUE 
real::uas42					!DUMMY VALUE 

real::dua1					!DUMMY VALUE 
real::dua2					!DUMMY VALUE 
real::dua3					!DUMMY VALUE 
real::dua4					!DUMMY VALUE 

real::h1					!DUMMY VALUE 
real::h2					!DUMMY VALUE 

real::ucent					!DUMMY VALUE 
real::vcent					!DUMMY VALUE 
real::hcent					!DUMMY VALUE 
real::uvnc					!DUMMY VALUE 
real::ccent					!DUMMY VALUE 
real::invcnt					!DUMMY VALUE 
real::pres1					!DUMMY VALUE 

real::xnn					!DUMMY VALUE 
real::ynn					!DUMMY VALUE 
real::rnn					!DUMMY VALUE 

real::vp1					!DUMMY VALUE 
real::vp3					!DUMMY VALUE 
real::vp4					!DUMMY VALUE 

real::uq41					!DUMMY VALUE 
real::uq42					!DUMMY VALUE 

real::rc1					!DUMMY VALUE 
real::rc2					!DUMMY VALUE 

real::flu11					!DUMMY VALUE 
real::flu21					!DUMMY VALUE 
real::flu31					!DUMMY VALUE 
real::flu41					!DUMMY VALUE 

real::fdc1					!DUMMY VALUE 
real::fdc2					!DUMMY VALUE 
real::fdc3					!DUMMY VALUE 
real::fdc4					!DUMMY VALUE
 
real::duv1					!DUMMY VALUE 
real::duv2					!DUMMY VALUE 
real::duv3					!DUMMY VALUE 
real::duv4					!DUMMY VALUE 

real,allocatable,dimension(:)::flu_turb		!DUMMY VALUE  CANDICATE FOR DELETION JUST FOR TURBULENCE
!****************************************************************************************



!****************************************************************************************
!CONVECTIVE FLUXES
!****************************************************************************************
real::temprxy_cvnormals			!DUMMY VALUE 
real::tempx_cvnormals			!DUMMY VALUE 
real::tempy_cvnormals			!DUMMY VALUE 
real::temp_u				!DUMMY VALUE 
real::temp_v				!DUMMY VALUE 
real::temp_w				!DUMMY VALUE 
real::usc				!DUMMY VALUE 
real::fgp1				!DUMMY VALUE 
real::fgp2				!DUMMY VALUE 
real::fgp3				!DUMMY VALUE 
real::fgp4				!DUMMY VALUE 
real::pstar				!DUMMY VALUE 
real::upd_rho_out			!DUMMY VALUE 
real::upd_momxout			!DUMMY VALUE 
real::upd_momyout			!DUMMY VALUE 
real::upd_ener_out			!DUMMY VALUE 
!****************************************************************************************



!****************************************************************************************
!OUTPUTS TO TECPLOT
!****************************************************************************************
real,allocatable,dimension(:)::vel_u		!velocity u component
real,allocatable,dimension(:)::vel_v		!velocity v component
real,allocatable,dimension(:)::vel_tot		!velocity module
!****************************************************************************************



!****************************************************************************************
!OUTPUTS TO SCREEN
!****************************************************************************************
integer::np_supersonic		!number of supersonic points        

real::max_mach			!maximum mach number      
real::min_mach			!minimum mach number    
real::min_pres			!minimum pressure     
real::max_pres			!maximum pressure         
real::min_rho			!minimum density     
real::max_rho			!maximum density         
real::velxmin			!minimum x-velocity    
real::velxmax			!maximum x-velocity      
real::velymin			!minimum y-velocity       
real::velymax			!maximum y-velocity      
real::xkmin			!minimum k  
real::xkmax			!maximum k      
real::xemin			!minimum epsilon   
real::xemax			!maximum epsilon  
real::tempemin			!minimum temperature      
real::tempemax			!maximum temperature

real::local_u			!u velocity      
real::local_v			!v velocity
real::local_uv			!velocity module
real::local_pp			!pressure
real::temperature		!temperature
real::speed_sound		!speed of sound 
real::local_mach		!local mach number qz/cc

real,allocatable,dimension(:)::temperature_array			!TEMPERATURE ARRAY
!****************************************************************************************



!****************************************************************************************
!CONVERGENCE CHECK AND STOPPING CRITERIA
!****************************************************************************************
integer::stop_program
!****************************************************************************************



end module shared_data
