!FILE       :	sol_init.f90
!UNIT NAME  :	sol_init	(SUBROUTINE)
!DESCRIPTION:	This subroutine initialize the solution using the values of inital guess
!		Written by Joel GUERRERO
!		REV01-01/2007
!		Email: joegi.geo@yahoo.com

subroutine sol_init


use shared_data

implicit none





!****************************************************************************************
!LOCAL VARIABLES
!
real::xrho						!DELTA RHO
!
!ATTENTION: ALL DUMMY VARIABLES DECLARED AS LOCAL VARIABLES ARE TEMPORAL
!THEY ARE ONLY USED WITHIN THE SUBROUTINE
!****************************************************************************************

!****************************************************************************************
!LOCAL VARIABLES DECLARATIONS
!
allocate(vars_actual(num_var,n_ver))			!ARRAY OF ACTUAL VARIABLES
allocate(vars_prev(num_var,n_ver))			!ARRAY OF UPDATED VARIABLES
allocate(pres(n_ver))					!PRESSURE


xrho		=1.0e-10
iter_prev	=0					!INITIAL ITERATION
time_prev	=0.0					!INITIAL TIME
!****************************************************************************************



!****************************************************************************************
!VARIABLES INITIALIZATION
!
do is=1,n_ver

    vars_actual(1,is)    = rho_in				!DENSITY
    vars_actual(2,is)    = rho_in*velxin			!DENSITY*UVEL (XMOMENTUN)
    vars_actual(3,is)    = rho_in*velyin			!DENSITY*VVEL (YMOMENTUN)
    vars_actual(4,is)    = ener_in				!ENERGY
    vars_actual(5,is)    = xkin					!FOR TURBULENCE NOT IMPLEMNTED
    vars_actual(6,is)    = xein					!FOR TURBULENCE NOT IMPLEMNTED                           

enddo 

do is=1,n_ver

    vars_prev(1,is)    = 0
    vars_prev(2,is)    = 0
    vars_prev(3,is)    = 0
    vars_prev(4,is)    = 0
    vars_prev(5,is)    = 0
    vars_prev(6,is)    = 0                              

enddo 
!****************************************************************************************



!****************************************************************************************
!REINITIALIZATION FROM A FILE  -EULER_SOL-
!
if(restart.eq.1) then

	open(20,file="EULER_SOL",status="unknown")
	rewind(20)

	do is=1,n_ver

		read(20,*) (vars_actual(i,is),i=1,4)

	enddo


    	read(20,*) iter_prev,time_prev
	close(20)

endif
!****************************************************************************************



!****************************************************************************************
!SWAPPING INITIAL PYSICAL SOLUTION
!
do is=1,n_ver

	do ivar=1,num_var

			vars_prev(ivar,is) = vars_actual(ivar,is)

	enddo

enddo
!****************************************************************************************



!****************************************************************************************
!PRESSURE INITIAL COMPUTATION
!
do is=1,n_ver

	if(vars_actual(1,is).lt.xrho) then

        print *,array_boundary_ver(is),coor(1,is),coor(2,is),pres(is)
        stop 'ATTENTION:   DENSITY < 0  (PRES_UPDATE) '

	endif

	pres(is)=	gam1*(vars_actual(4,is) - 0.5*(vars_actual(2,is)*vars_actual(2,is)&
			+vars_actual(3,is)*vars_actual(3,is))/vars_actual(1,is))

	if(pres(is).lt.xrho) then

		print *,array_boundary_ver(is),coor(1,is),coor(2,is),pres(is)
       		stop 'ATTENTION:   PRESSURE < 0  (PRES_UPDATE) '

	endif

enddo
!****************************************************************************************



!****************************************************************************************
!ITERATION AND TIME INIT
!
if(restart.eq.1) then
	iter_max		=	iter_max + iter_prev
	iter_actual		=	iter_prev
	time_actual		=	time_prev
	eps				=	1.0e-2
else
	iter_actual		=	iter_prev
	time_actual		=	time_prev
	eps				=	1.0e-2
endif
!****************************************************************************************



end subroutine sol_init
