!FILE       :	vtk_output.f90
!UNIT NAME  :	vtk_output	(SUBROUTINE)
!DESCRIPTION:	This subroutine dump data to VTK legacy format file
!		It dumps the last iteration
!		Written by Joel GUERRERO
!		REV01-01/2007, REV02-09/2020
!		Email: joegi.geo@yahoo.com

subroutine vtk_output


use shared_data

implicit none





!***************************************************************************
!COMPUTE VELOCITIES FROM MOMENTUM
!
do is=1,n_ver

	vel_u(is)	=vars_actual(2,is)/vars_actual(1,is)
	vel_v(is)	=vars_actual(3,is)/vars_actual(1,is)
	vel_tot(is)	=sqrt(vel_u(is)*vel_u(is) + vel_v(is)*vel_v(is))

enddo
!***************************************************************************



!***************************************************************************
!DUMP MESH DATA TO vtk_output.vtk FILE
!
open(51,file='vtk_output.vtk',status='unknown')

write(51,100) '# vtk DataFile Version 4.2'
write(51,100) 'Unstructured Grid Example'
write(51,100) 'ASCII'


write(51,*)
write(51,100) 'DATASET UNSTRUCTURED_GRID'
write(51,101) 'POINTS ',n_ver,' float'

	
do i=1,n_ver
	write(51,102) coor(1,i),coor(2,i),0.0
end do


write(51,*)
write(51,103) 'CELLS ',n_ele,3*n_ele+n_ele


do it=1,n_ele
	write(51,104) 3,connectivity(1,it)-1,connectivity(2,it)-1,connectivity(3,it)-1 
end do


write(51,*)
write(51,105) 'CELL_TYPES ',n_ele


do it=1,n_ele
	write(51,106) 5
end do


write(51,*)
write(51,107) 'POINT_DATA',n_ver
write(51,108) 'SCALARS pressure float'
write(51,108) 'LOOKUP_TABLE default'


do i=1,n_ver
	write(51,109) pres(i)
end do


write(51,*)
write(51,108) 'SCALARS density float'
write(51,108) 'LOOKUP_TABLE default'


do i=1,n_ver
	write(51,109) vars_actual(1,i)
end do


write(51,*)
write(51,108) 'SCALARS U_velocity float'
write(51,108) 'LOOKUP_TABLE default'


do i=1,n_ver
	write(51,109) vel_u(i)
end do


write(51,*)
write(51,108) 'SCALARS V_velocity float'
write(51,108) 'LOOKUP_TABLE default'


do i=1,n_ver
	write(51,109) vel_v(i)
end do


write(51,*)
write(51,108) 'VECTORS velocity_vectors float'
!write(51,*) 'LOOKUP_TABLE default'
do i=1,n_ver
	write(51,110) vel_u(i),vel_v(i),0.0
end do



!100 format(a)
!101 format(a,i,a)
!102 format(f,f,f)
!103 format(a,i,i)
!104 format(i,i,i,i)
!105 format(a,i)
!106 format(i)
!107 format(a,i)
!108 format(a)
!109 format(f)
!110 format(f,f,f)

100 format(a)
101 format(a,i10,a)
102 format(f14.5,f14.5,f14.5)
103 format(a,i10,i10)
104 format(i10,i10,i10,i10)
105 format(a,i10)
106 format(i10)
107 format(a,i10)
108 format(a)
109 format(f14.5)
110 format(f14.5,f14.5,f14.5)



close(51)
!***************************************************************************



end subroutine vtk_output
